local enums = require('consts.celeste_enums')
local drawableSprite = require('structs.drawable_sprite')
local directions =  {"Floor", "Left Wall", "Right Wall", "Ceiling"}

local PaintWall = {}


PaintWall.name = "SusanHelper/PaintLiquid"
PaintWall.depth = -13000
PaintWall.placements = {
    name = "Paint Wall",
    data = {
        width = 8,
        orientation = "Floor",
        depthModifier = 0,
        evil = true
    }
}


PaintWall.fieldInformation = {
    orientation = {
        options = directions
    }
}

PaintWall.canResize = {true, true}

local justifications = {
    ["Floor"] = {0.0, 0.0},
    ["Ceiling"] = {1.0, 0.0},
    ["Left Wall"] = {0.0, 1.0},
    ["Right Wall"] = {1.0, 0.0}
}

PaintWall.justification = function(room, entity)
    return table.unpack(justifications[entity.orientation])
end

local rotations = {
    ["Floor"] = 0,
    ["Ceiling"] = math.pi,
    ["Left Wall"] = -math.pi / 2,
    ["Right Wall"] = math.pi / 2
}

PaintWall.rotation = function(room, entity)
    return rotations[entity.orientation]
end

PaintWall.texture = "objects/paint/bigSwitch00"

PaintWall.scale = function(room, entity)
    local horizontal = entity.orientation == "Left Wall" or entity.orientation == "Right Wall"

    -- dirty awful hack (thank you CommunalHelper for the idea :gladstare:)
    if horizontal then
        entity.width = 8
    else
        entity.height = 8
    end

    local drawable = drawableSprite.fromTexture(PaintWall.texture, {x = entity.x, y = entity.y})
    if drawable then
        local scaleFactor
        if horizontal then
            scaleFactor = (entity.height) / (drawable.meta.realWidth)
        else
            scaleFactor = (entity.width) / (drawable.meta.realWidth)
        end
        return scaleFactor, 1.0
    end
    return 1.0, 1.0
end

return PaintWall

